@@ -6,7 +6,6 @@ import operator
 from unittest import TestCase
 
 import aioitertools as ait
-
 from .helpers import async_test
 
 slist = ["A", "B", "C"]
@@ -340,6 +339,15 @@ class ItertoolsTest(TestCase):
         with self.assertRaises(StopAsyncIteration):
             await ait.next(it)
 
+    @async_test
+    async def test_groupby_empty(self):
+        async def gen():
+            for _ in range(0):
+                yield  # Force generator with no actual iteration
+
+        async for _ in ait.groupby(gen()):
+            self.fail("No iteration should have happened")
+
     @async_test
     async def test_islice_bad_range(self):
         with self.assertRaisesRegex(ValueError, "must pass stop index"):
